*****************
The sherpa module
*****************

.. currentmodule:: sherpa

.. automodule:: sherpa

   .. rubric:: Functions

   .. autosummary::
      :toctree: api

      citation
      get_config
      get_include
      smoke
